@@ -1,9 +1,9 @@
 """
 
 """
-import datetime
 import json
 import zipfile
+from datetime import datetime
 
 import pandas as pd
 from notecoin.huobi.dataset.core import (Kline1DayDetail, Kline1MinDetail,
@@ -303,18 +303,26 @@ class SymbolHistory:
 
 def load_daily_all(period='1min',
                    data_type=ALL_DATA_TYPES[0],
+                   _type=ALL_TYPES[0],
                    date=datetime(2021, 5, 21),
                    download_dir='/root/workspace/tmp/coin/daily',
-                   delete_file=True):
+                   delete_file=True,
+                   overwrite=False,trade=False):
     download_dir2 = os.path.join(download_dir, date.strftime("%Y%m%d"))
     history = HistoryDownload(all_symbols=None,
                               data_type=data_type,
                               all_periods=[period],
+                              _type=_type,
                               start_date=date,
                               end_date=date,
                               download_dir=download_dir2)
-    history.download_klines()
     file_path = os.path.join(download_dir, f'{history.data_type}_{history.type}_{period}-{date.strftime("%Y%m%d")}.csv')
+    if os.path.exists(file_path) and not overwrite:
+        return file_path
+    if trade:
+        history.download_trades()
+    else:
+        history.download_klines()
 
     with open(file_path, 'w') as new_file:
         for item in list_file(download_dir2, deep=10):
